##############################################################################
#
# Copyright (c) 2004 Dinheiro Vivo <www.dinheirovivo.com.br>
#                    by Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>
# 
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
# 
##############################################################################

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass
from OFS.SimpleItem import SimpleItem

from Products.CMFCore.CMFCorePermissions import View

class PublicationBoxInformation(SimpleItem):
    """Represent a single selectable publication box.
    """

    __allow_access_to_unprotected_subobjects__ = 1

    def __init__(self,
                 id,
                 title='',
                 content_type=[],
                 icon_url='',
                 n_items=1,
                 n_searched_items=30,
                 search_states=['published'],
                 with_image=0,
                 images_folder='',
                 image_states=['visible'],
                 box_width='auto',
                 box_height='auto',
                 visible=1,
                 items=None):
        """Set up an instance.
        """

        self.id = id
        self.title = title
        self.content_type = content_type
        self.icon_url = icon_url
        self.n_items = n_items
        self.n_searched_items = n_searched_items
        self.search_states = search_states
        self.with_image = with_image
        self.images_folder = images_folder
        self.image_states = image_states
        self.box_width = box_width
        self.box_height = box_height
        self.visible = visible
        if items is not None:
            self.items = items
        else:
            self.items = []

    security = ClassSecurityInfo()

    security.declarePrivate('clone')
    def clone(self):
        """Return a newly-created PublicationBoxInterface just like us.
        """

        return self.__class__(id=self.id,
                              title=self.title,
                              content_type=self.content_type,
                              icon_url=self.icon_url,
                              n_items=self.n_items,
                              n_searched_items=self.n_searched_items,
                              search_states=self.search_states,
                              with_image=self.with_image,
                              images_folder=self.images_folder,
                              image_states=self.image_states,
                              box_width=self.box_width,
                              box_height=self.box_height,
                              visible=self.visible,
                              items=self.items)

    security.declareProtected(View, 'getName')
    def getName(self):
        """Return the Publication Box title.
        """

        return self.title

    security.declareProtected(View, 'getContent_type')
    def getContent_type(self):
        """Return the Publication Box content type.
        """

        return self.content_type[:]

    security.declareProtected(View, 'getIcon_url')
    def getIcon_url(self):
        """Return the Publication Box icon url.
        """

        return self.icon_url

    security.declareProtected(View, 'getN_items')
    def getN_items(self):
        """Return the number of items that has need the Publication Box.
        """

        return self.n_items

    security.declareProtected(View, 'getN_searched_items')
    def getN_searched_items(self):
        """Return the number of searched items that is displayed
        is the Publication Box select setup.
        """

        return self.n_searched_items

    security.declareProtected(View, 'getSearch_states')
    def getSearch_states(self):
        """Return the Publication Box item states that are searched.
        """

        return self.search_states[:]

    security.declareProtected(View, 'getWith_image')
    def getWith_image(self):
        """Return whether the Publication Box was a image.
        """

        return self.with_image

    security.declareProtected(View, 'getImages_folder')
    def getImages_folder(self):
        """Return the Publication Box image folder repository.
        """

        return self.images_folder

    security.declareProtected(View, 'getImage_states')
    def getImage_states(self):
        """Return the Publication Box image states that are searched.
        """

        return self.image_states[:]

    security.declareProtected(View, 'getBox_width')
    def getBox_width(self):
        """Return the Publication Box box width.
        """

        return self.box_width

    security.declareProtected(View, 'getBox_height')
    def getBox_height(self):
        """Return the Publication Box box height.
        """

        return self.box_height

    security.declareProtected(View, 'getVisible')
    def getVisible(self):
        """Return whether the Publication Box is visible.
        """

        return self.visible

    security.declareProtected(View, 'getItems')
    def getItems(self):
        """Return the copy of list of the Publication Box.
        """

        return self.items[:]

InitializeClass(PublicationBoxInformation)

